/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.mentions.internal.listeners;

import javax.inject.Inject;
import javax.inject.Named;
import javax.inject.Provider;
import javax.inject.Singleton;

import org.xwiki.bridge.event.ApplicationReadyEvent;
import org.xwiki.component.annotation.Component;
import org.xwiki.component.phase.Initializable;
import org.xwiki.component.phase.InitializationException;
import org.xwiki.mentions.internal.MentionsEventExecutor;
import org.xwiki.observation.AbstractEventListener;
import org.xwiki.observation.event.Event;

import com.xpn.xwiki.XWikiContext;

/**
 * Listen for the application to be ready before starting the mentions task consumers.
 *
 * @version $Id: d7b037be932cc20e9d8b4662d4f0392b233b1d96 $
 * @since 12.6
 */
@Component
@Singleton
@Named("MentionsApplicationReadyEventListener")
public class MentionsApplicationReadyEventListener extends AbstractEventListener implements Initializable
{
    @Inject
    private MentionsEventExecutor eventExecutor;

    @Inject
    @Named("readonly")
    private Provider<XWikiContext> contextProvider;

    /**
     * Default constructor.
     */
    public MentionsApplicationReadyEventListener()
    {
        super("MentionsApplicationReadyEventListener", new ApplicationReadyEvent());
    }

    @Override
    public void onEvent(Event event, Object source, Object data)
    {
        // In case of ApplicationReadyEvent (when the wiki starts)
        this.eventExecutor.startThreads();
    }

    @Override
    public void initialize() throws InitializationException
    {
        // If the application is already initialized we start the threads immediately
        // (e.g. in case of extension install).
        if (this.contextProvider.get() != null) {
            this.eventExecutor.startThreads();
        }
    }
}
